Learn R Programming

ufRisk (version 1.0.7)

print.ufRisk: Print Method for Objects of Class 'ufRisk'

Description

This function regulates how objects of class ufRisk are printed.

Usage

# S3 method for ufRisk
print(x, ...)

Value

None

Arguments

x

an object of class ufRisk; for the current package version, only the function br_test returns such an object.

...

implemented for compatibility with the generic function; additional arguments, however, will not affect this print method.

Author

  • Sebastian Letmathe (Scientific Employee) (Department of Economics, Paderborn University)

  • Dominik Schulz (Scientific Employee) (Department of Economics, Paderborn University),